@@ -16,17 +16,20 @@ from .__utils import sizeof_fmt, zipdir
 
 def put_cmd_args(parser: argparse.ArgumentParser):
     parser.add_argument('type', type=str, choices=[
-                        'ids', 'protocol', 'master-script', 'task-script'], help='artifact type')
-    parser.add_argument('namespace', type=str.lower)
+        'ids', 'protocol', 'master-script', 'task-script'],
+                        help='artifact type')
+    parser.add_argument('namespace', type=__namespace_type),
     parser.add_argument('slug', type=str.lower)
     parser.add_argument('version', type=__version_type)
     parser.add_argument('folder', type=__folder_type,
                         help='path to folder to be uploaded')
     parser.add_argument(
-        '--force', '-f', action='store_true', help='force overwrite of an existing artifact'
+        '--force', '-f', action='store_true',
+        help='force overwrite of an existing artifact'
     )
     parser.add_argument(
-        '--ignore-ssl', '-i', action='store_true', help='ignore the SSL certificate verification'
+        '--ignore-ssl', '-i', action='store_true',
+        help='ignore the SSL certificate verification'
     )
 
     parser.add_argument('--org', help='org slug', type=str)
@@ -34,7 +37,8 @@ def put_cmd_args(parser: argparse.ArgumentParser):
     parser.add_argument('--auth-token', help='authorization token', type=str)
 
     parser.add_argument(
-        '--config', '-c', help='JSON file with configuration', type=argparse.FileType('r')
+        '--config', '-c', help='JSON file with configuration',
+        type=argparse.FileType('r')
     )
 
     parser.set_defaults(func=__cmd)
@@ -52,6 +56,33 @@ def __folder_type(arg_value):
     raise argparse.ArgumentTypeError('Not valid folder path provided!')
 
 
+def __namespace_type(arg_value: str,
+                     ns_pattern=re.compile("^private-[0-9a-zA-Z-]+$")) -> str:
+    """
+    Namespace validation function. Namespace must start with 'private-' and
+    only contains alphanumeric characters and hyphens. A hyphen cannot
+    succeed another hyphen. An exception is raised for invalid namespaces.
+
+    Args:
+        arg_value (str): namespace
+        ns_pattern (re.Pattern): namespace validation regex.
+
+     Returns:
+         arg_value (str): validated namespace
+    """
+
+    # validate namespace
+    if (not ns_pattern.match(arg_value) or
+            arg_value.endswith("-") or
+            re.search(r"--", arg_value)):
+        raise argparse.ArgumentTypeError(
+            f"Invalid namespace {arg_value}. Namespace must start with "
+            f"'private-' followed by alphanumeric characters or single "
+            f"hyphens.")
+
+    return arg_value
+
+
 def __ensure_args(args: argparse.Namespace):
     # from env
     env_prefix = 'TS_'
@@ -118,7 +149,8 @@ def __cmd(args):
             raise Exception('No build ID found in upload response!')
 
         print('Build started', flush=True)
-        print("Note: A local script interruption doesn't stop a remote build!", flush=True)
+        print("Note: A local script interruption doesn't stop a remote build!",
+              flush=True)
 
         last_status = None
         prev_next_token = ''
