@@ -25,8 +25,9 @@ from .__util_validation import validate_file_meta, validate_file_tags, validate_
 COMPLETED = 'completed'
 FAILED = 'failed'
 
-LOG_TAG_PRE_FUNCTION = 'pre_function_call'
-LOG_TAG_POST_FUNCTION = 'post_function_call'
+# TODO these should be logged at a more verbose level than debug
+# LOG_TAG_PRE_FUNCTION = 'pre_function_call'
+# LOG_TAG_POST_FUNCTION = 'post_function_call'
 LOG_TAG_SCRIPT_STARTED = 'script_started'
 LOG_TAG_SCRIPT_ENDED = 'script_ended'
 
@@ -36,20 +37,21 @@ if 'default_print' not in __builtins__:
 def wrap_log(func_name):
     def return_wrapper(fn):
         def wrapper(*args, **kwargs):
-            id = str(uuid.uuid4())
-            Context.log.log({
-                'level': 'debug',
-                'tag': LOG_TAG_PRE_FUNCTION,
-                'funcName': func_name,
-                'id': id
-            })
+            # TODO log at a finer level
+            # id = str(uuid.uuid4())
+            # Context.log.log({
+            #     'level': 'debug',
+            #     'tag': LOG_TAG_PRE_FUNCTION,
+            #     'funcName': func_name,
+            #     'id': id
+            # })
             result = fn(*args, **kwargs)
-            Context.log.log({
-                'level': 'debug',
-                'tag': LOG_TAG_POST_FUNCTION,
-                'funcName': func_name,
-                'id': id
-            })
+            # Context.log.log({
+            #     'level': 'debug',
+            #     'tag': LOG_TAG_POST_FUNCTION,
+            #     'funcName': func_name,
+            #     'id': id
+            # })
             return result
         return wrapper
     return return_wrapper
@@ -484,9 +486,10 @@ def run(input, context_from_arg, func, correlation_id, func_dir,
     context = Context(context_from_arg, datalake, ids_util, log, command, fileinfo)
     func_module, func_name = resolve_func(func_dir, func)
     try:
-        log.log({ 'level': 'debug', 'tag': LOG_TAG_PRE_FUNCTION, 'funcName': f'{func_module}.{func_name}' })
+        # TODO log at a finer level
+        # log.log({ 'level': 'debug', 'tag': LOG_TAG_PRE_FUNCTION, 'funcName': f'{func_module}.{func_name}' })
         result = getattr(importlib.import_module(func_module), func_name)(input, context)
-        log.log({ 'level': 'debug', 'tag': LOG_TAG_POST_FUNCTION, 'funcName': func_name })
+        # log.log({ 'level': 'debug', 'tag': LOG_TAG_POST_FUNCTION, 'funcName': func_name })
 
         if store_output:
             output_response(storage, { 'type': COMPLETED, 'result': result }, correlation_id)
