@@ -1,4 +1,7 @@
 import os
+from pathlib import Path
+from typing import Tuple
+
 import boto3
 from botocore.client import Config
 import gzip
@@ -11,7 +14,6 @@ import shutil
 import tempfile
 import io
 from urllib.parse import urlencode
-import logging
 
 from .__util_versioned_ref import VersionedRef
 from .__util_metadata import FIELDS
@@ -52,6 +54,13 @@ def getOrEmptyString(dic, key, default=''):
     return val
 
 
+class InvalidPathException(Exception):
+    def __init__(self, path, reason):
+        super().__init__(f'Invalid path {path}: {reason}')
+        self.path = path
+        self.reason = reason
+
+
 def getUpdatedPipelineHistoryStr(pipeline_id, existing_pipeline_history):
     new_pipeline_history = ''
     if existing_pipeline_history == '':
@@ -63,6 +72,7 @@ def getUpdatedPipelineHistoryStr(pipeline_id, existing_pipeline_history):
             new_pipeline_history = existing_pipeline_history + "," + pipeline_id
     return new_pipeline_history
 
+
 class S3FileobjUploader:
     def __init__(self, s3, fileobj, params, options={'disable_gzip': False}):
         self.s3 = s3
@@ -126,6 +136,7 @@ class S3FileobjUploader:
             if self.stream.tell() >= MULTIPART_SIZE:
                 self._uploadPart()
 
+
 class Datalake:
     def __init__(self, endpoint):
         #boto3.set_stream_logger(name='botocore', level=logging.DEBUG)
@@ -198,6 +209,13 @@ class Datalake:
 
         return result
 
+    @classmethod
+    def _is_file_path_valid(cls, filepath) -> Tuple[bool, str]:
+        filepath = Path(filepath)
+        if filepath.name == '..' or '..' in (parent.name for parent in filepath.parents):
+            return False, 'Path cannot contain a directory ".."'
+        return True, ''
+
     def write_file(self, context, content, file_name, file_category, raw_file, file_meta, ids = None, source_type = None, labels = []):
         bucket = raw_file['bucket']
         raw_file_key = raw_file['fileKey']
@@ -218,8 +236,13 @@ class Datalake:
         else:
             source_type = getOrEmptyString(file_meta, FIELDS['SOURCE_TYPE'], 'unknown')
 
-        org_slug, source_id, raw_file_path = match.groups()
-        file_key = os.path.join(org_slug, source_id, file_category, raw_file_path, file_name)
+        org_slug, destination_or_source_id, raw_file_path = match.groups()
+
+        file_key = os.path.join(org_slug, destination_or_source_id, file_category, raw_file_path, file_name)
+        is_valid_file_key, reason = self._is_file_path_valid(file_key)
+        if not is_valid_file_key:
+            raise InvalidPathException(file_key, reason)
+
         file_id = str(uuid4())
         pipelineConfig = context.get('pipelineConfig', {})
         pipeline_history_str = getUpdatedPipelineHistoryStr(getOrEmptyString(context, 'pipelineId'),
@@ -236,6 +259,8 @@ class Datalake:
             FIELDS['RAW_FILE_ID']: getOrEmptyString(file_meta, FIELDS['FILE_ID']),
             FIELDS['CUSTOM_METADATA']: getOrEmptyString(file_meta, FIELDS['CUSTOM_METADATA']),
             FIELDS['CUSTOM_TAGS']: getOrEmptyString(file_meta, FIELDS['CUSTOM_TAGS']),
+            FIELDS['SOURCE_ID']: getOrEmptyString(file_meta, FIELDS['SOURCE_ID']),
+            FIELDS['DESTINATION_ID']: getOrEmptyString(file_meta, FIELDS['DESTINATION_ID']),
             FIELDS['SOURCE_NAME']: getOrEmptyString(file_meta, FIELDS['SOURCE_NAME']),
             FIELDS['SOURCE_TYPE']: source_type,
             FIELDS['TRACE_ID']: getOrEmptyString(file_meta, FIELDS['TRACE_ID']),
@@ -496,9 +521,9 @@ class Datalake:
         params = {
             'Bucket': target_file['bucket'],
             'Key': file_key
-                .replace('/RAW/', '/TMP/')
-                .replace('/IDS/', '/TMP/')
-                .replace('/PROCESSED/', '/TMP/'),
+                .replace('/RAW/', '/TMP/', 1)
+                .replace('/IDS/', '/TMP/', 1)
+                .replace('/PROCESSED/', '/TMP/', 1),
             'ContentType': 'application/json'
         }
         if sse_kms_key_id != '':
