@@ -10,9 +10,12 @@ FIELDS = {
     'FILE_PATH': 'ts_file_path', # how to specify this?
     'FILE_NAME': 'ts_file_name',
 
+    'SOURCE_ID': 'ts_integration_source',
     'SOURCE_TYPE': 'ts_source_type',
     'SOURCE_NAME': 'ts_source_name',
 
+    'DESTINATION_ID': 'ts_destination_id',
+
     'RAW_FILE_ID': 'ts_source_file_id',
     'RAW_FILE_VERSION': 'ts_raw_file_version',
 
